==> flink-1.12.7-src.tgz: flink-1.12.7/flink-core/src/test/java/org/apache/flink/api/common/typeutils/base/LongValueSerializerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.common.typeutils.base;

import org.apache.flink.api.common.typeutils.SerializerTestBase;
import org.apache.flink.api.common.typeutils.TypeSerializer;
import org.apache.flink.types.LongValue;

import java.util.Random;

/** A test for the {@link LongValueSerializer}. */
public class LongValueSerializerTest extends SerializerTestBase<LongValue> {

    @Override
    protected TypeSerializer<LongValue> createSerializer() {
        return new LongValueSerializer();
    }

    @Override
    protected int getLength() {
        return 8;
    }

    @Override
    protected Class<LongValue> getTypeClass() {
        return LongValue.class;
    }

    @Override
    protected LongValue[] getTestData() {
        Random rnd = new Random(874597969123412341L);
        long rndLong = rnd.nextLong();

        return new LongValue[] {
            new LongValue(0L),
            new LongValue(1L),
            new LongValue(-1L),
            new LongValue(Long.MAX_VALUE),
            new LongValue(Long.MIN_VALUE),
            new LongValue(rndLong),
            new LongValue(-rndLong)
        };
    }
}

==> flink-2.1.1-src.tgz: flink-2.1.1/flink-core/src/test/java/org/apache/flink/api/common/typeutils/base/LongValueSerializerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.common.typeutils.base;

import org.apache.flink.api.common.typeutils.SerializerTestBase;
import org.apache.flink.api.common.typeutils.TypeSerializer;
import org.apache.flink.types.LongValue;

import java.util.Random;

/** A test for the {@link LongValueSerializer}. */
class LongValueSerializerTest extends SerializerTestBase<LongValue> {

    @Override
    protected TypeSerializer<LongValue> createSerializer() {
        return new LongValueSerializer();
    }

    @Override
    protected int getLength() {
        return 8;
    }

    @Override
    protected Class<LongValue> getTypeClass() {
        return LongValue.class;
    }

    @Override
    protected LongValue[] getTestData() {
        Random rnd = new Random(874597969123412341L);
        long rndLong = rnd.nextLong();

        return new LongValue[] {
            new LongValue(0L),
            new LongValue(1L),
            new LongValue(-1L),
            new LongValue(Long.MAX_VALUE),
            new LongValue(Long.MIN_VALUE),
            new LongValue(rndLong),
            new LongValue(-rndLong)
        };
    }
}
